@@ -9,11 +9,11 @@
 	($dispflag nil))
     (declare (special $dispflag))
     (unless (and ($listp eqns) ($listp vars))
-      (maxima-error "eliminate: The arguments must both be lists"))
+      (merror (intl:gettext "eliminate: arguments must both be lists.")))
     (when (> ($length vars) l)
-      (maxima-error "eliminate: More variables than equations"))
+      (merror (intl:gettext "eliminate: more variables than equations.")))
     (when (= l 1)
-      (maxima-error "eliminate: Can't eliminate from only one equation"))
+      (merror (intl:gettext "eliminate: can't eliminate from only one equation.")))
     (when (= ($length vars) l)
       (setq vars ($reverse vars))
       (setq sv (maref vars 1))
