@@ -106,8 +106,8 @@
 	  *n *opers-list *out *ratweights *tr-warn-break* *transl-backtrace*
 	  *transl-debug* *transl-file-debug* *warned-fexprs*
 	  *warned-mode-vars* *warned-un-declared-vars* *zexptsimp? |-1//2|
-	  -sqrt2//2 -sqrt3//2 |1//2| adn* aexprp algfac* algnotexact
-	  aliaslist alpha *alphabet* arrays aryp assigns atp atvars baktrcl
+	  -sqrt3//2 |1//2| adn* aexprp algfac* algnotexact
+	  aliaslist alpha *alphabet* arrays aryp assigns *atp* atvars baktrcl
 	  bfhalf bfmhalf bigfloat%e bigfloat%pi bigfloatone bigfloatzero
 	  bindlist bvars *mdebug*
 	  declares defined_variables defintdebug derivflag derivlist
@@ -117,16 +117,16 @@
 	  forms-to-compile-queue fourth%pi fr-factor fundefsimp gauss
 	  generate-atan2 genpairs genvar half%pi half%pi3 hmodulus
 	  implicit-real in-p infinitesimals infinities inratsimp inside-mprog
-	  integerl islinp lexprs limit-answers limitp linel
+	  integerl *islinp* lexprs limit-answers limitp linel
 	  linelable lnorecurse local loclist low* maplp master-mesfile mdop
-	  meta-prop-l meta-prop-p mfexprp minpoly* mlocp mm* modulus mopl
+	  meta-prop-l meta-prop-p mfexprp minpoly* mlocp mm* modulus *mopl*
 	  mplc* mprogp mproplist mspeclist mspeclist2 msump munbindp
 	  need-prog? negprods negsums nn* noevalargs noitems nonintegerl
 	  nounl nounsflag opers opers-list opexprp outargs1 outargs2 outfiles
 	  plusflag preserve-direction prods putl radcanp radpe rd*
 	  real-infinities realonlyratnum refchkl return-mode returns rulefcnl
 	  rulesw scanmapp sfindex sign-imag-errp simplimplus-problems
-	  *small-primes* specials sqrt2//2 sqrt3//2 state-pdl $stringdisp substp
+	  *small-primes* specials sqrt3//2 state-pdl $stringdisp substp
 	  sums tellratlist timesinp timesp tr-abort tr-progret tr-unique
 	  transl-file translate-time-evalables transp
 	  tstack typel user-mesfile user-timesofar varlist wflag
