@@ -23,13 +23,12 @@
   "If TRUE, messages about map/fullmap truncating on the shortest list
 or if apply is being used are printed.")
   
-(declare-top (special 
-		      derivflag derivlist $labels
-		      $values $functions $arrays $rules $gradefs $dependencies $aliases
+(declare-top (special derivflag derivlist $labels $values $functions $arrays 
+                      $rules $gradefs $dependencies $aliases
 		      $myoptions $props genvar $maxposex $maxnegex $expop $expon
 		      $numer state-pdl *mdebug* refchkl baktrcl
 		      $norepeat $detout $doallmxops $doscmxops opers
-		      mopl $powerdisp $dispflag *alphabet* $%% %e-val
+		      *mopl* $powerdisp $dispflag *alphabet* $%% %e-val
 		      outfiles $macros linel $ratfac $ratwtlvl
 		      $operators $partswitch *gcdl*
 		      *builtin-$props* $infolists))
@@ -475,6 +474,10 @@ is EQ to FNNAME if the latter is non-NIL."
         (merror (intl:gettext "apply: found ~M evaluates to ~M where a function was expected.") name val)
         (merror (intl:gettext "apply: found ~M where a function was expected.") val))))
 
+;; To store the value of $errormsg in mbind. This value is looked up in the
+;; routine mbind-doit. This is a hack to get the expected behavior, when the
+;; option variable $errormsg is used as a local variable in a block.
+(defvar *$errormsg-value* nil)
 
 (defun mbind-doit (lamvars fnargs fnname)
   "Makes a new frame where the variables in the list LAMVARS are bound
@@ -497,7 +500,14 @@ wrapper for this."
     (let ((var (car vars)))
       (if (not (symbolp var))
 	  (merror (intl:gettext "Only symbols can be bound; found: ~M") var))
-      (let ((value (if (boundp var) (symbol-value var) munbound)))
+      (let ((value (if (boundp var)
+                       (if (eq var '$errormsg)
+                           ;; Do not take the actual value of $errormsg. It is
+                           ;; always NIL at this point, but the value which
+                           ;; is stored in *$errormsg-value*.
+                           *$errormsg-value*
+                           (symbol-value var))
+                       munbound)))
 	(mset var (car args))
 	(psetq bindlist (cons var bindlist)
 	       mspeclist (cons value mspeclist))))))
@@ -507,6 +517,10 @@ wrapper for this."
   (handler-case
       (let ((old-bindlist bindlist) win)
 	(declare (special bindlist))
+        ;; At this point store the value of $errormsg in a global. The macro
+        ;; with-$error sets the value of $errormsg to NIL, but we need the
+        ;; actual value in the routine mbind-doit.
+        (setq *$errormsg-value* $errormsg)
 	(unwind-protect
 	     (prog1
 		 (with-$error (mbind-doit lamvars fnargs fnname))
@@ -1430,7 +1444,7 @@ wrapper for this."
 	  (t (putprop var val prop)))
     (if (and (safe-get var 'op) (operatorp1 var)
 	     (not (member (setq var (get var 'op)) (cdr $props) :test #'eq)))
-	(setq mopl (cons var mopl)))
+	(setq *mopl* (cons var *mopl*)))
     (add2lnc (getop var) $props)))
 
 (defun linchk (var)
@@ -1541,7 +1555,8 @@ wrapper for this."
     (zl-remprop fun 'translated-mmacro)
     (mremprop fun 't-mfexpr)
     (zl-remprop fun 'function-mode)
-    (if (not (getl fun '(a-expr a-subr)))
+    (when (not (getl fun '(a-expr a-subr)))
+	(zl-remprop fun 'once-translated)
 	(zl-remprop fun 'translated))))
 
 (defun remove-transl-array-fun-props (fun)
