@@ -29,17 +29,59 @@
 (defmvar generate-atan2 t "Controls whether RPART will generate ATAN's
 			or ATAN2's, default is to make ATAN2's")
 
+;;; Realpart gives the real part of an expr.
+
 (defmfun $realpart (xx) (car (trisplit xx)))
 
+(defprop $realpart %realpart verb)
+(defprop %realpart $realpart noun)
+(defprop %realpart simp-realpart operators)
+
+(defun simp-realpart (expr z simpflag)
+  (oneargcheck expr)
+  (setq z (simpcheck (cadr expr) simpflag))
+  (let ((sgn nil))
+    (cond ((mnump z) z)
+          ((eq (setq sgn ($csign z)) '$imaginary)
+           0)
+          ((eq sgn '$complex)
+           (cond ((complex-number-p ($expand z) 'bigfloat-or-number-p)
+                  ($realpart z))
+                 (t 
+                  (eqtest (list '(%realpart) z) expr))))
+          (t 
+           (eqtest (list '(%realpart) z) expr)))))
+
+;;; Imagpart gives the imaginary part of an expr.
+
 (defmfun $imagpart (xx) (cdr (trisplit xx)))
 
-;;;Rectform gives a result of the form a+b*%i.
+(defprop $imagpart %imagpart verb)
+(defprop %imagpart $imagpart noun)
+(defprop %imagpart simp-imagpart operators)
+
+(defun simp-imagpart (expr z simpflag)
+  (oneargcheck expr)
+  (setq z (simpcheck (cadr expr) simpflag))
+  (let ((sgn nil))
+    (cond ((mnump z) 0)
+          ((eq (setq sgn ($csign z)) '$imaginary)
+           (mul -1 '$%i z))
+          ((eq sgn '$complex)
+           (cond ((complex-number-p ($expand z) 'bigfloat-or-number-p)
+                  ($imagpart z))
+                 (t 
+                  (eqtest (list '(%imagpart) z) expr))))
+          (t 
+           (eqtest (list '(%imagpart) z) expr)))))
+
+;;; Rectform gives a result of the form a+b*%i.
 
 (defmfun $rectform (xx)
   (let ((ris (trisplit xx)))
     (add (car ris) (mul (cdr ris) '$%i))))
 
-;;;Polarform gives a result of the form a*%e^(%i*b).
+;;; Polarform gives a result of the form a*%e^(%i*b).
 
 (defmfun $polarform (xx)
   (cond ((and (not (atom xx)) (member (caar xx) '(mequal mlist $matrix) :test #'eq))
@@ -52,27 +94,62 @@
 ;;; be syntactically real without being real (e.g. sqrt(x), x<0).  Thus
 ;;; Cabs must lead an independent existence from Abs.
 
-(defmfun $cabs (xx) (cabs ($rectform xx)))
+(defmfun $cabs (xx) (cabs xx))
+
+(defprop $cabs %cabs verb)
+(defprop %cabs $cabs noun)
+(defprop %cabs simp-cabs operators)
+
+(defun simp-cabs (expr z simpflag)
+  (oneargcheck expr)
+  (setq z (simpcheck (cadr expr) simpflag))
+  (let ((sgn nil))
+    (cond ((member (setq sgn ($csign z)) '($complex $imaginary))
+           (cond ((complex-number-p ($expand z) 'bigfloat-or-number-p)
+                  (simplify (list '(mabs) z)))
+                 (t
+                  (eqtest (list '(mabs) z) expr))))
+          ((eq sgn '$zero)
+           0)
+          ((member sgn '($pos $pz))
+           z)
+          ((eq sgn '$neg)
+            (mul -1 z))
+          (t 
+           (eqtest (list '(mabs) z) expr)))))
 
 ;;; Carg gives the complex argument.
+
 (defmfun $carg (xx)
-  (cond ((and (not (atom xx)) (member (caar xx) '(mequal mlist $matrix) :test #'eq))
+  (cond ((and (not (atom xx)) 
+              (member (caar xx) '(mequal mlist $matrix) :test #'eq))
 	 (cons (car xx) (mapcar #'$carg (cdr xx))))
 	(t (cdr (absarg xx)))))
 
-(defvar absflag nil)
+(defprop $carg %carg verb)
+(defprop %carg $carg noun)
+(defprop %carg simp-carg operators)
 
-;; The function of Absflag is to communicate to Absarg that only the absolute
-;; value part of the result is wanted.  This allows Absarg to avoid asking
-;; questions irrelevant to the absolute value.  For instance, Cabs(x) is
-;; invariably Abs(x), while the complex phase may be 0 or %pi.  Note also
-;; the steps taken in Absarg to assure that Asksign's will happen before Sign's
-;; as often as possible, so that, for instance, Abs(x) can be simplified to
-;; x or -x if the sign of x must be known for some other reason.  These
-;; techniques, however, are not perfect.
+(defun simp-carg (expr z simpflag)
+  (oneargcheck expr)
+  (setq z (simpcheck (cadr expr) simpflag))
+  (let ((sgn nil))
+    (cond ((eq z '$%i)
+           (div '$%pi 2))
+          ((member (setq sgn ($csign z)) '($complex $imaginary))
+           (cond ((complex-number-p ($expand z) 'bigfloat-or-number-p)
+                  ($carg z))
+                 (t 
+                  (eqtest (list '(%carg) z) expr))))
+          ((member sgn '($pos $pz $zero))
+           0)
+          ((eq sgn '$neg)
+            '$%pi)
+          (t 
+           (eqtest (list '(%carg) z) expr)))))
 
 ;; The internal cabs, used by other Macsyma programs.
-(defmfun cabs (xx) (let ((absflag t)) (car (absarg xx))))
+(defmfun cabs (xx) (car (absarg xx t)))
 
 ;; Some objects can only appear at the top level of a legal simplified
 ;; expression: CRE forms and equations in particular.
@@ -158,9 +235,20 @@
     (cond ((fixnump pow)	   ; Sqrt(-x) -> %i*sqrt(x)
 	   (let ((sp (risplit (cadr l))))
 	     (cond ((= pow -1)
-		    (let ((a2+b2 (spabs sp)))
-		      (cons (div (car sp) a2+b2)
-			    (mul -1 (div (cdr sp) a2+b2)))))
+		    ;; Handle the case of 1/(x+%i*y) carefully.  This
+		    ;; is needed if x and y are (Lisp) numbers to
+		    ;; prevent spurious underflows/overflows.  See Bug
+		    ;; 2954472.
+		    ;; https://sourceforge.net/tracker/?func=detail&atid=104933&aid=2954472&group_id=4933.
+		    ;;
+		    (if (and (or (numberp (car sp))
+				 (ratnump (car sp)))
+			     (or (numberp (cdr sp))
+				 (ratnump (cdr sp))))
+			(sprecip sp)
+			(let ((a2+b2 (spabs sp)))
+			  (cons (div (car sp) a2+b2)
+				(mul -1 (div (cdr sp) a2+b2))))))
 		   ((> (abs pow) $maxposex)
 		    (cond ((=0 (cdr sp))
 			   (cons (powers (car sp) pow) 0))
@@ -186,29 +274,56 @@
 		    (setq ris (risplit (cadr l)))
 		    (or (= (caddr pow) 2) (=0 (cdr ris)))))
 	   (cond ((=0 (cdr ris))
-		  (case (cond ((mnegp (car ris)) '$negative)
-			      (implicit-real '$positive)
-			      (t (asksign (car ris))))
-		    ($negative (risplit (mul2 (power -1 pow) (power (neg (car ris)) pow))))
+		  (case (cond ((mnegp (car ris)) '$neg)
+			      (implicit-real '$pos)
+			      (t ($sign (car ris)))) ; Use $sign not asksign
+		    ($neg (risplit (mul2 (power -1 pow) 
+                                         (power (neg (car ris)) pow))))
 		    ($zero (cons (power 0 pow) 0))
-		    (t (cons (power (car ris) pow) 0))))
+                    ($pos (cons (power (car ris) pow) 0)) ; Add the case $pos
+                    (t
+                     ;; The sign is unknown. Return a general form.
+                     (let ((sp (risplit (caddr l)))
+		           (aa (absarg1 (cadr l))))
+                       (let ((pre (mul (powers '$%e (mul (cdr aa) (mul (cdr sp) -1)))
+                                       (powers (car aa) (car sp))))
+                             (post (add (mul (cdr sp) (take '(%log) (car aa)))
+                                        (mul (car sp) (cdr aa)))))
+                       (cons (mul pre (take '(%cos) post))
+                             (mul pre (take '(%sin) post))))))))
 		 (t
 		  (let ((abs2 (spabs ris))
 			(n (abs (cadr pow)))
 			(pos? (> (cadr pow) -1)))
-		    (let ((abs (power abs2 (1//2))))
-		      (divcarcdr
-		       (expanintexpt
-			(cons (power (add abs (car ris)) (1//2))
-			      (porm (let ((a pos?)
-					  (b (eq (asksign (cdr ris)) '$negative)))
-				      (cond (a (not b))
-					    (b t)))
-				    (power (sub abs (car ris)) (1//2))))
-			n)
-		       (if pos?
-			   (power 2 (div n 2))
-			   (power (mul 2 abs2) (div n 2)))))))))
+		    (let ((abs (power abs2 (1//2)))
+                          (sign-imagpart ($sign (cdr ris)))) ; Do we know the sign?
+                      (cond ((member sign-imagpart '($neg $pos))
+                             (divcarcdr
+                               (expanintexpt
+                                 (cons (power (add abs (car ris)) (1//2))
+                                       (porm (let ((a pos?)
+                                                   (b (eq (asksign (cdr ris)) 
+                                                          '$negative)))
+                                               (cond (a (not b))
+                                                     (b t)))
+                                             (power (sub abs (car ris)) (1//2))))
+                                 n)
+                               (if pos?
+                                   (power 2 (div n 2))
+                                   (power (mul 2 abs2) (div n 2)))))
+                            (t
+                             ;; The sign is unknown. Return a general form.
+                             (let ((sp (risplit (caddr l)))
+                                   (aa (absarg1 (cadr l))))
+                               (let ((pre (mul (powers '$%e 
+                                                       (mul (cdr aa) 
+                                                       (mul (cdr sp) -1)))
+                                               (powers (car aa) (car sp))))
+                                     (post (add (mul (cdr sp) 
+                                                     (take '(%log) (car aa)))
+                                                (mul (car sp) (cdr aa)))))
+                                 (cons (mul pre (take '(%cos) post))
+                                       (mul pre (take '(%sin) post))))))))))))
 	  ((and (floatp (setq ris (cadr l))) (floatp pow))
 	   (risplit (let (($numer t))
 		      (exptrl ris pow))))
@@ -226,6 +341,7 @@
 (defun risplit-noun (l)
   (cons (simplify (list '(%realpart) l)) (simplify (list '(%imagpart) l))))
 
+
 (defun absarg1 (arg)
   (let ((arg1 arg) ($keepfloat t))
     (cond ((and (or (free arg '$%i)
@@ -264,6 +380,9 @@
 	   (let ((ris (risplit (cadr l))))
 	     (cons (simplify (list* (ncons (caar l)) (car ris) (cddr l)))
 		   (simplify (list* (ncons (caar l)) (cdr ris) (cddr l))))))
+          ((eq (caar l) '$conjugate)
+           (cons (simplify (list '(%realpart) (cadr l)))
+                 (mul -1 (simplify (list '(%imagpart) (cadr l))))))
 	  ((let ((ass (assoc (caar l)
 			     '((%sin %cosh %cos . %sinh)
 			       (%cos %cosh %sin . %sinh)
@@ -304,7 +423,7 @@
 	   (cons l 0))
 	  ((or (arcp (caar l)) (eq (caar l) '$atan2))
 	   (let ((ans (risplit (let (($logarc t))
-				 (ssimplifya l)))))
+				 (resimplify l)))))
 	     (when (eq (caar l) '$atan2)
 	       (setq ans (cons (sratsimp (car ans)) (sratsimp (cdr ans)))))
 	     (if (and (free l '$%i) (=0 (cdr ans)))
@@ -321,7 +440,7 @@
 	     (cons (div (add orig cc) 2) (div (sub orig cc) (mul 2 '$%i)))))
 	  ;; Look for a risplit-function on the property list to handle the
 	  ;; realpart and imagpart for this function.
-	  ((setq op (get (mop l) 'risplit-function))
+          ((setq op (safe-get (mop l) 'risplit-function))
 	   (funcall op l))
 ;;; ^ All the above are guaranteed pure real.
 ;;; The handling of lists and matrices below has to be thought through.
@@ -336,8 +455,12 @@
 ;;; to functions known by risplit, such as the more useless trigonometrics.
 	  ((let ((foot (coversinemyfoot l)))
 	     (and foot (risplit foot))))
-	  ((or (get (mop l) 'commutes-with-conjugate)
-	       (get (mop l) 'conjugate-function))
+          ((or (safe-get (mop l) 'real-valued)
+               (decl-realp (mop l)))
+           ;; Simplification for a real-valued function
+           (cons l 0))
+          ((or (safe-get (mop l) 'commutes-with-conjugate)
+               (safe-get (mop l) 'conjugate-function))
 	   ;; A function with Mirror symmetry. The general expressions for
 	   ;; the realpart and imagpart simplifies accordingly.
 	   (cons (mul (div 1 2)
@@ -356,7 +479,12 @@
 	   (risplit-noun l))
 	  ((and (eq (caar l) '%product) (not (free (cadr l) '$%i)))
 	   (risplit-noun l))
-	  (t (cons l 0)))))
+          (($subvarp l)
+           ;; return a real answer for subscripted variable
+           (cons l 0))
+          (t
+           (cons (list '(%realpart simp) l)
+                 (list '(%imagpart simp) l))))))
 
 (defun coversinemyfoot (l)
   (prog (recip)
@@ -371,7 +499,53 @@
 	((=1 c) 1)
 	(t (power c d))))
 
-(defun spabs (sp) (add (powers (car sp) 2) (powers (cdr sp) 2)))
+(defun spabs (sp)
+  ;; SP is a cons of the real part and imaginary part of a complex
+  ;; number.  SPABS computes the sum of squares of the real and
+  ;; imaginary parts.
+  (add (powers (car sp) 2)
+       (powers (cdr sp) 2)))
+
+;; Compute 1/(x+%i*y) when both x and y are Lisp numbers or Maxima
+;; rationals.  Return a cons of the real and imaginary part of the
+;; result.  We count on the underlying Lisp to be able to compute (/
+;; (complex x y)) accurately and without unnecessary overflow or
+;; underflow..  If not, complain to your Lisp vendor.  Well, it seems
+;; that Clisp, CMUCL, and SBCL do a nice job.  But others apparently
+;; do not.  (I tested ecl 9.12.3 and ccl 1.4, which both fail.)
+;; Workaround those deficiencies.
+(defun sprecip (sp)
+  (destructuring-bind (x . y)
+      sp
+    #+(or cmu sbcl)
+    (let* ((x (bigfloat:to x))
+	   (y (bigfloat:to y))
+	   (q (bigfloat:/ (bigfloat:complex x y))))
+      (cons (to (bigfloat:realpart q))
+	    (to (bigfloat:imagpart q))))
+    #-(or cmu sbcl)
+    (let ((x (bigfloat:to x))
+	  (y (bigfloat:to y)))
+      ;; 1/(x+%i*y).
+      ;;
+      ;; Assume abs(x) > abs(y).  Let r = y/x.  Then
+      ;; 1/(x+%i*y) = 1/x/(1+%i*r)
+      ;;            = (1-%i*r)/(x*(1+r*r))
+      ;;
+      ;; The case for abs(x) <= abs(y) is similar with r = x/y:
+      ;; 1/(x+%i*y) = 1/y/(r+%i)
+      ;;            = (r-%i)/(y*(1+r^2))
+      (if (> (bigfloat:abs x) (bigfloat:abs y))
+	  (let* ((r (bigfloat:/ y x))
+		 (dn (bigfloat:* x (bigfloat:+ 1 (bigfloat:* r r)))))
+	    (cons (to (bigfloat:/ dn))
+		  (to (bigfloat:/ (bigfloat:- r) dn))))
+	  (let* ((r (bigfloat:/ x y))
+		 (dn (bigfloat:* y (bigfloat:+ 1 (bigfloat:* r r)))))
+	    (cons (to (bigfloat:/ r dn))
+		  (to (bigfloat:/ (bigfloat:- dn)))))))))
+      
+  
 
 
 (defvar negp* (let ((l (list nil nil t t))) (nconc l l)))
@@ -454,10 +628,24 @@
       (simplify '$%pi)
       0))
 
+
+;; absarg
 ;; returns pair (abs . arg)
 ;; if absflag is true, arg result is not guaranteed to be correct
-(defun absarg (l)
-  (setq l ($expand l))
+
+;; The function of Absflag is to communicate that only the absolute
+;; value part of the result is wanted.  This allows Absarg to avoid asking
+;; questions irrelevant to the absolute value.  For instance, Cabs(x) is
+;; invariably Abs(x), while the complex phase may be 0 or %pi.  Note also
+;; the steps taken in Absarg to assure that Asksign's will happen before Sign's
+;; as often as possible, so that, for instance, Abs(x) can be simplified to
+;; x or -x if the sign of x must be known for some other reason.  These
+;; techniques, however, are not perfect.
+
+(defun absarg (l &optional (absflag nil))
+;; Commenting out the the expansion of the expression l. It seems to be not
+;; necessary, but can cause expression swelling (DK 01/2010).
+;  (setq l ($expand l))
   (cond ((atom l)
 	 (cond ((eq l '$%i)
 		(cons 1 (simplify '((mtimes) ((rat simp) 1 2) $%pi))))
@@ -465,16 +653,20 @@
 		(cons (abs l) (argnum l)))
 	       ((member l '($%e $%pi) :test #'eq) (cons l 0))
 	       ((eq l '$infinity) (cons '$inf '$ind))
-	       ((kindp l '$complex) (cons (list '($cabs) l)
-					  (list '($carg) l)))
+               ((decl-complexp l)
+                (cons (list '(mabs simp) l) ; noun form with mabs
+                      (list '(%carg simp) l)))
 	       (absflag (cons (take '(mabs) l) 0))
 	       (t
-		(let ((gs (if (eq rischp l) '$positive (asksign l))))
-		  (cond ((eq gs '$positive) (cons l 0))
+                ;; At this point l is representing a real value. Try to 
+                ;; determine the sign and return a general form when the sign is
+                ;; unknown.
+		(let ((gs (if (eq rischp l) '$pos ($sign l))))
+		  (cond ((member gs '($pos $pz)) (cons l 0))
 			((eq gs '$zero) (cons 0 0))
-			((eq gs '$negative)
+			((eq gs '$neg)
 			 (cons (neg l) (simplify '$%pi)))
-			(t (cons (take '(mabs) l) 0)))))))
+			(t (cons (take '(mabs) l) (genatan 0 l))))))))
 	((member (caar l) '(rat bigfloat) :test #'eq)
 	 (cons (list (car l) (abs (cadr l)) (caddr l))
 	       (argnum (cadr l))))
@@ -486,10 +678,9 @@
 	     (())
 	   (unless n
 	     (return (cons (muln absl t) (2pistrip (addn argl t)))))
-	   (setq abars (absarg (car n)))))
+	   (setq abars (absarg (car n) absflag))))
 	((eq (caar l) 'mexpt)
-	 (let ((aa (let ((absflag nil))	;; we always need arg of base of exponent
-		     (absarg (cadr l))))
+	 (let ((aa (absarg (cadr l) nil)) ; we always need arg of base of exponent
 	       (sp (risplit (caddr l)))
 	       ($radexpand nil))
 	   (cons (mul (powers (car aa) (car sp))
@@ -512,9 +703,9 @@
 		       (if (eq (caar l) '%tan)
 			   (div (take '(%sinh) 2frst) (take '(%sin) 2scnd))
 			   (div (take '(%sin) 2frst) (take '(%sinh) 2scnd)))))))
-	((specrepp l) (absarg (specdisrep l)))
+	((specrepp l) (absarg (specdisrep l) absflag))
 	((let ((foot (coversinemyfoot l)))
-	   (and foot (not (=0 (cdr (risplit (cadr l))))) (absarg foot))))
+	   (and foot (not (=0 (cdr (risplit (cadr l))))) (absarg foot absflag))))
 	(t
 	 (let ((ris (trisplit l)))
 	   (xcons
@@ -536,6 +727,13 @@
 	(take '(%atan) (m// num den)))))
 
 (defun absarg-mabs (l)
-  (if (eq (csign l) t)
-      (if (member (caar l) '(mabs %cabs) :test #'eq) l (list '(%cabs simp) l))
-      (take '(mabs) l)))
+  (cond ((eq (csign l) t)
+         (if (member (caar l) '(mabs %cabs) :test #'eq) 
+             l 
+             (list '(mabs simp) l))) ; mabs and not %cabs as noun form
+        ((member ($csign l) '($complex $imaginary))
+         ;; Do not try to simplify a complex expression at this point,
+         ;; this would cause an endless loop. Return a noun form.
+         (list '(mabs simp) l))
+        (t 
+         (take '(mabs) l))))
